function runpower_salient_3gen_2motors_read;
global degit Uit it Pstatic Qstatic PM1 PM2 PG2 PG3;

%_______________________INPUT FROM USER___________________________
Pmech=input('Pmech load(kWt)= ');
Welhz=input('HZ= ');
Pstatic=input('Pstatic load(kWt)= ');
Qstatic=input('Qstatic load(kvar)= ');

%__________READ MACHINE DATA FROM file: Machine_data.txt__________
n=6;                                      %number of buses
PM1=dlmread('Machine_data.txt',' ',[2 0 2 0])/100; %percent load M1
PM2=dlmread('Machine_data.txt',' ',[2 1 2 1])/100; %percent load M2
PG2=dlmread('Machine_data.txt',' ',[5 0 5 0])/100; %percent load G2
PG3=dlmread('Machine_data.txt',' ',[5 1 5 1])/100; %percent load G3
Gen1= dlmread('Machine_data.txt',' ',[24 0 24 5]);
Gen2= dlmread('Machine_data.txt',' ',[28 0 28 5]);
Gen3= dlmread('Machine_data.txt',' ',[32 0 32 5]);
Mot1= dlmread('Machine_data.txt',' ',[36 0 36 5]);
Mot2= dlmread('Machine_data.txt',' ',[36 0 36 5]);

%_____________________REFERENCE PU CALCULATIONS_____________________
Sref=Pmech*1000;                           %Reference power=shaft power needed
Wel=Welhz*2*pi;                            %Rotational speed in rad/s
Pstatic=Pstatic*1000/Sref;
Qstatic=Qstatic*1000/Sref;

Welg1_nominal=(Gen1(5)*Gen1(4)/60)*2*pi;    %nominal generator1 el speed, rad/s
Keg1=Gen1(6)/Welg1_nominal;  %Ke generator1 calculation RMS line-line, induced rated voltage


Uref=Keg1*Wel                               %Reference voltage=Generator EMF
Iref=Sref/(1.732*Uref);       %Reference current obtained from power and voltage
Zref=(Uref*Uref)/Sref;                      %reference impedance 

%_______________________________MACHINE DATA in PU______________________________
%_Generator1:
Xqg1=Gen1(1)/(1000*Zref)*Wel;              %ohm /phase
Xdg1=Gen1(2)/(1000*Zref)*Wel;              %ohm /phase
Rg1=(Gen1(3)/1000)/Zref;                   %ohm /phase
Ygen1=[Xqg1;Xdg1;Rg1];
%_Generator2:
Welg2_nominal=(Gen2(5)*Gen2(4)/60)*2*pi;    %nominal gen2 el speed, rad/s
Keg2=Gen2(6)/Welg2_nominal;%Ke gen2 calculation RMS line-line, induced rated voltage
Xqg2=Gen2(1)/(1000*Zref)*Wel;               %ohm /phase
Xdg2=Gen2(2)/(1000*Zref)*Wel;               %ohm /phase
Rg2=(Gen2(3)/1000)/Zref;                    %ohm /phase
Ygen2=[Xqg1;Xdg1;Rg1];
%_Generator3:
Welg3_nominal=(Gen3(5)*Gen3(4)/60)*2*pi;    %nominal gen3 el speed, rad/s
Keg3=Gen3(6)/Welg3_nominal;%Ke gen3 calculation RMS line-line, induced rated voltage
Xqg3=Gen3(1)/(1000*Zref)*Wel;               %ohm /phase
Xdg3=Gen3(2)/(1000*Zref)*Wel;               %ohm /phase
Rg3=(Gen3(3)/1000)/Zref;                    %ohm /phase
Ygen3=[Xqg1;Xdg1;Rg1];
%_Motor1:
Welm1_nominal=(Mot1(5)*Mot1(4)/60)*2*pi;    %nominal motor1 el speed, rad/s
Kem1=Mot1(6)/Welm1_nominal;%Ke motor1 calculation RMS line-line, induced rated voltage
Xqm1=Mot1(1)/(1000*Zref)*Wel;               %ohm /phase
Xdm1=Mot1(2)/(1000*Zref)*Wel;               %ohm /phase
Rm1=(Mot1(3)/1000)/Zref;                    %ohm /phase
Ymot1=[Xqm1;Xdm1;Rm1];
%_Motor2:
Welm2_nominal=(Mot2(5)*Mot2(4)/60)*2*pi;    %nominal motor1 el speed, rad/s
Kem2=Mot2(6)/Welm2_nominal;%Ke motor1 calculation RMS line-line, induced rated voltage
Xqm2=Mot2(1)/(1000*Zref)*Wel;               %ohm /phase
Xdm2=Mot2(2)/(1000*Zref)*Wel;               %ohm /phase
Rm2=(Mot2(3)/1000)/Zref;                    %ohm /phase
Ymot2=[Xqm1;Xdm1;Rm1];

%_____________________________EMF OF THE MACHINES_________________________________
Efg1=Keg1*Wel/(Uref);                  %Generator1 voltage (magnitude) RMS line-neutral
Efg2=Keg2*Wel/(Uref);                  %Generator2 voltage (magnitude) RMS line-neutral
Efg3=Keg3*Wel/(Uref);                  %Generator3 voltage (magnitude) RMS line-neutral
Efm1=Kem1*Wel/(Uref);                  %Motor1 voltage (magnitude) RMS line-neutral
Efm2=Kem2*Wel/(Uref);                  %Motor2 voltage (magnitude) RMS line-neutral

%_____________________________CONNECTIONS MATRIX_________________________________
Conn=[1 1 0 0 0 0;
      1 1 1 1 1 1; 
      0 1 1 0 0 0; 
      0 1 0 1 0 0;
      0 1 0 0 1 0;
      0 1 0 0 0 1];

%n=6;                                  %n-number of machines(rows and columns in a matrix)
Z=[ ; ; ; ; ];
%_____________________________MATRIX____________________________________
for DIM=1:1:3;                       %3-dimension matrix
                                     %1-dimension Xq
                                     %2-dimension Xd
                                     %3-dimension R
imp=[Ygen1(DIM);0;Ymot1(DIM);Ygen2(DIM);Ygen3(DIM);Ymot2(DIM)];
for r=1:1:n;                         %Generator always connected to bus 2
    l=1;
    Z(l, r, DIM)=Conn(l, r)*imp(1);
end
for l=1:1:n;
    r=1;
    Z(l, r, DIM)=Conn(l, r)*imp(1);
end

for x=2:1:n;                          %Motors connected always to bus 2
for l=2:1:n;                          
    r=x;
    Z(l, r, DIM)=Conn(l, r)*imp(x);
end
for r=2:1:n;
    l=x;
    Z(l, r, DIM)=Conn(l, r)*imp(x);
end
end
 Z(2, 2, DIM)=1/(1/imp(1)+1/imp(3)+1/imp(4)+1/imp(5)++1/imp(6));   
 %Diagonal impedance of bus 2 always a sum of all machines
end
Z(:,:,1)
Z(:,:,2)
Z(:,:,3)

 %_______Initial gueses__________________________________
 deg(1,1)=0;
 deg(1,2)=0;
 deg(1,3)=0;
 deg(1,4)=0;
 deg(1,5)=0;
 deg(1,6)=0;
 U(1,1)=Efg1;
 U(1,2)=1;       
 U(1,3)=Efm1;
 U(1,4)=Efg2;
 U(1,5)=Efg3;
 U(1,6)=Efm2;
 
 t=0;
 it=0;
 
 while it<10;
salient_power_flow_3gen_2motors(Z,deg,U,t);
deg((it+1),:)=degit;
U((it+1),:)=Uit;
t=it;
 end
 deg
 U
               
end